pub struct PackRewrite {
pub pack: PathBuf,
pub keep: Vec<Hash>,
}Expand description
A pack scheduled to be rewritten without some of its objects.
Fields
pack: PathBufPath of the pack being rewritten.
keep: Vec<Hash>Objects the replacement pack will contain: the pack’s live objects that are not covered by a loose copy or a healthy pack, sorted.